# hippogryph

[![PyPI - Version](https://img.shields.io/pypi/v/hippogryph.svg)](https://pypi.org/project/hippogryph)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hippogryph.svg)](https://pypi.org/project/hippogryph)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install hippogryph
```

## License

`hippogryph` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
